/*  pmode4game_private.h - PMODE 4 playing cards library for the Disk Basic.
   
    By Pierre Sarrazin <http://sarrazip.com/>.
    This file is in the public domain.
*/

#ifndef _H_pmode4game_private
#define _H_pmode4game_private


#include "pmode4game.h"


extern TextAreaScrollCallback textAreaScrollCallback;
extern void *textAreaScrollCallbackUserData;
extern byte colorInversionMask;
extern BOOL drawRowOverGlyphWhenColorsInverted;
extern BOOL drawColumnAtRightOfGlyphWhenColorsInverted;
extern BOOL transparentSpaceChar;


#endif  /* _H_pmode4game_private */
